@@ -6,6 +6,7 @@ import time
 import logging
 import wsaccel
 import sys
+import json
 import ScratchEncoder
 ws = websocket.WebSocket()
 encoder = ScratchEncoder.Encoder()
@@ -130,22 +131,6 @@ class s2py():
         requests.put("https://scratch.mit.edu/site-api/users/curators-in/" +
                      str(sid) + "/invite_curator/?usernames=" + user, headers=self.headers,)
 
-    def postProjectComment(self, pid, content, parent_id="", commentee_id=""):
-        self.headers['referer'] = (
-            "https://scratch.mit.edu/projects/" + str(pid)
-        )
-        data = {
-            "commentee_id": commentee_id,
-            "content": content,
-            "parent_id": parent_id,
-        }
-        return requests.post(
-            "https://api.scratch.mit.edu/proxy/comments/project/"
-            + str(pid) + "/",
-            headers=self.headers,
-            data=json.dumps(data),
-        )
-
     def postStudioComment(self, sid, content, parent_id="", commentee_id=""):
         self.headers['referer'] = (
             "https://scratch.mit.edu/studios/" + str(sid) + "/comments/"
@@ -322,15 +307,16 @@ class s2py():
             time.sleep(0.1)
             logging.info('Re-connected to wss://clouddata.scratch.mit.edu')
 
-    def readCloudVar(self, name, limit=""):
-        if limit == "":
-            limit = 1000
-        resp = requests.get("https://clouddata.scratch.mit.edu/logs?projectid=" +
+    def readCloudVar(self, name, limit="1000"):
+        try:
+            resp = requests.get("https://clouddata.scratch.mit.edu/logs?projectid=" +
                             str(PROJECT_ID)+"&limit="+str(limit)+"&offset=0").json()
-        for i in resp:
-            x = i['name']
-            if x == ('☁ ' + str(name)):
-                return i['value']
+            for i in resp:
+                x = i['name']
+                if x == ('☁ ' + str(name)):
+                    return i['value']
+        except:
+            return 'Sorry, there was an error.'
 
     def cloudConnect(self, pid):
         global ws
@@ -343,6 +329,7 @@ class s2py():
             'user': self.username,
             'project_id': str(pid)
         })
+        time.sleep(1.5)
 
 
 def sendPacket(packet):
